==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QTextFrame_shell.h <==
#ifndef QTEXTFRAME_SHELL_H
#define QTEXTFRAME_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qtextobject.h>
#include <QtJambi/QtJambiAPI>
#include <QTextCursor>
#include <QTextFrame>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QTextFrame_shell : public QTextFrame, public QtJambiShellInterface
{
public:
    QTextFrame_shell(QTextDocument* doc0);
    ~QTextFrame_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextFrame_access : public QTextFrame
{
};

#endif // QTEXTFRAME_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QTextFrame_shell.h <==
#ifndef QTEXTFRAME_SHELL_H
#define QTEXTFRAME_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qtextobject.h>
#include <QtJambi/QtJambiAPI>
#include <QTextCursor>
#include <QTextFrame>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QTextFrame_shell : public QTextFrame, public QtJambiShellInterface
{
public:
    QTextFrame_shell(QTextDocument* doc0);
    ~QTextFrame_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QTextFrame_mshell;
    friend class QTextFrame_oshell;
};


class QTextFrame_mshell : public QTextFrame_shell
{
public:
    using QTextFrame_shell::QTextFrame_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QTextFrame_oshell : public QTextFrame_mshell
{
public:
    using QTextFrame_mshell::QTextFrame_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextFrame_access : public QTextFrame
{
};

#endif // QTEXTFRAME_SHELL_H
